package cz.moneta.test.regression.backoffice.callcenter.jenkinstests.ccretail.cczakladbanka;

import cz.moneta.test.dsl.Harness;
import cz.moneta.test.dsl.util.credentials.Keys;
import cz.moneta.test.dsl.util.task.ufo.operations.OperationsTasks;
import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.TestCase;
import cz.moneta.test.harness.annotations.TestScenario;
import cz.moneta.test.harness.support.auth.Credentials;
import cz.moneta.test.harness.support.auth.Key;
import org.junit.jupiter.api.BeforeAll;

import static cz.moneta.test.harness.annotations.Environment.PPE;
import static cz.moneta.test.harness.annotations.Environment.TST1;

@TestScenario(name = "Activites on card")
public class ActivitiesOnCard {
    private String rcOfExistingClient;
    private String numberOfDebitCard;
    private OperationsTasks operationsTasks;

    @BeforeAll
    public void getInfo(Harness harness) {
        operationsTasks = harness.tasks().ufo().operations();
        rcOfExistingClient = harness.getSystemOrConfigValue("cc.activitesOnCardClient.rc");
        numberOfDebitCard = harness.getSystemOrConfigValue("cc.numberOfDebitCard.number");
    }

    @TestCase(name = "Bank - activities on card", environments = {PPE, TST1})
    @JiraTestCase(id = "CC-T2200")
    public void activitiesOnCard(Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {

        harness.withUfo()
                .openLoginPage()
                .then(operationsTasks.login().withCredentials(credentials))
                .then(operationsTasks.searchClient().byRc(rcOfExistingClient))
                .checkClientRc(rcOfExistingClient)
                .clickDebitCard()
                .checkRcOfHolder(rcOfExistingClient)
                .clickCardActivities()
                .checkListRowInTable()
                .checkInformationAboutCardHolder("Informace o držiteli karty")
                .checkPKHolderLabel("STEJNE JMENO")
                .checkCardNumberLabel(numberOfDebitCard)
                .clickBack()
                .checkRcOfHolder(rcOfExistingClient)
                .clickAccountBlocking()
                .checkListOfBlockedFinancialResources()
                .clickBack()
                .checkRcOfHolder(rcOfExistingClient);
    }
}
